@@ -1,5 +1,7 @@
 #!/usr/bin/env perl
 
+# ABSTRACT - A script to test some functionalities of FASTX::Abi
+
 use 5.018;
 use warnings;
 use FindBin qw($Bin);
@@ -10,27 +12,27 @@ use Term::ANSIColor;
 my $test_het = "$Bin/../data/hetero.ab1";
 my $test_omo = "$Bin/../data/mt.ab1";
 
-#$test = $ARGV[0] if (defined $ARGV[0] and -e "$ARGV[0]");
-
-
 
+# Import a "heterozigous" chromatogram
 my $fastq_h = FASTX::Abi->new({
   filename  => "$test_het",
   trim_ends => 1,
 });
 
+# Import a standard (non hetero) chromatogram
 my $fastq_o = FASTX::Abi->new({
   filename  => "$test_omo",
   trim_ends => 1,
 });
 
-for my $o ($fastq_h, $fastq_o) {
-  say color('bold'), "Name   :\t",   $o->{filename}, color('reset');
-  say "Iso_seq:\t",$o->{iso_seq};
-  say "Diffs  :\t",  $o->{diff};
-  my $info = $o->get_trace_info();
+# Print properties and FASTQ for both objects
+for my $trace_object ($fastq_h, $fastq_o) {
+  say color('bold'), "Name   :\t",   $trace_object->{sequence_name} , color('reset'), " [", $trace_object->{filename} , "]";
+  say "Iso_seq:\t",$trace_object->{iso_seq};
+  say "Diffs  :\t",  $trace_object->{diff}, "\t", join(', ', @{ $trace_object->{diff_array}});
+  my $info = $trace_object->get_trace_info();
   print color('blue'), Dumper $info;
-  say color('yellow'),substr($o->get_fastq(), 0, 44), color('reset'),'...';
+  say color('yellow'),substr($trace_object->get_fastq(), 0, 44), color('reset'),'...';
 }
 
 say color('bold'),  "NOW TESTING ERROR", color('reset');
